pub trait AdapterExecuteMsg: Serialize { }Expand description
Trait indicates that the type is used as an app message
in the ExecuteMsg enum.
Enables Into<ExecuteMsg> for BOOT fn-generation support.
pub trait AdapterExecuteMsg: Serialize { }Trait indicates that the type is used as an app message
in the ExecuteMsg enum.
Enables Into<ExecuteMsg> for BOOT fn-generation support.