Proxy Asset

Proxy assets are objects that describe an asset and a way to calculate that asset’s value against a base asset.

Details

A proxy asset is composed of two components.

  • The asset, which is an AssetInfo.
  • The PriceSource which is an enum that indicates how to calculate the value for that asset.

The base asset is the asset for which price_source in None. There should only be ONE base asset when configuring your proxy

Structs

  • represents the conversion of an asset in terms of the provided asset Example: provided asset is ETH and the price source for ETH is the pair ETH/USD, the price is 100USD/ETH then AssetConversion { into: USD, ratio: 100}

Enums

  • Provides information on how to calculate the value of an asset
  • Provides information on how to calculate the value of an asset